==> 1.0.0.zip: terraform-provider-dynamix/internal/service/cloudapi/disks/flattens/flatten_data_source_disk_list_unattached.go <==
package flattens

import (
	"context"
	"encoding/json"
	"fmt"

	"github.com/google/uuid"
	"github.com/hashicorp/terraform-plugin-framework/diag"
	"github.com/hashicorp/terraform-plugin-framework/types"
	"github.com/hashicorp/terraform-plugin-log/tflog"
	decort "repository.basistech.ru/BASIS/decort-golang-sdk"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/flattens"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/disks/models"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/disks/utilities"
)

// DiskListUnattachedDataSource flattens data source for disk list unattached.
// Return error in case data source is not found on the platform.
// Flatten errors are added to tflog.
func DiskListUnattachedDataSource(ctx context.Context, state *models.DataSourceDiskListUnattachedModel, c *decort.DecortClient) diag.Diagnostics {
	tflog.Info(ctx, "Start flattens.DiskListUnattachedDataSource")

	diags := diag.Diagnostics{}

	diskList, diags := utilities.DataSourceDiskListUnattachedCheckPresence(ctx, state, c)
	if diags.HasError() {
		return diags
	}

	tflog.Info(ctx, "flattens.DiskListUnattachedDataSource: before flatten")

	id := uuid.New()
	*state = models.DataSourceDiskListUnattachedModel{
		ByID:        state.ByID,
		AccountName: state.AccountName,
		DiskMaxSize: state.DiskMaxSize,
		Status:      state.Status,
		AccountID:   state.AccountID,
		SepID:       state.SepID,
		PoolName:    state.PoolName,
		Type:        state.Type,
		SortBy:      state.SortBy,
		Page:        state.Page,
		Size:        state.Size,
		Timeouts:    state.Timeouts,

		// computed fields
		Id:         types.StringValue(id.String()),
		EntryCount: types.Int64Value(int64(diskList.EntryCount)),
	}

	items := make([]models.ItemDiskUnattachedModel, 0, diskList.EntryCount)
	for _, recordDisk := range diskList.Data {
		diskAcl, _ := json.Marshal(recordDisk.ACL)
		d := models.ItemDiskUnattachedModel{
			CKey:                types.StringValue(recordDisk.CKey),
			Meta:                flattens.Meta(ctx, recordDisk.Meta),
			AccountID:           types.Int64Value(int64(recordDisk.AccountID)),
			AccountName:         types.StringValue(recordDisk.AccountName),
			ACL:                 types.StringValue(string(diskAcl)),
			BootPartition:       types.Int64Value(int64(recordDisk.BootPartition)),
			CreatedTime:         types.Int64Value(int64(recordDisk.CreatedTime)),
			DeletedTime:         types.Int64Value(int64(recordDisk.DeletedTime)),
			Description:         types.StringValue(recordDisk.Description),
			DestructionTime:     types.Int64Value(int64(recordDisk.DestructionTime)),
			DiskPath:            types.StringValue(recordDisk.DiskPath),
			GID:                 types.Int64Value(int64(recordDisk.GID)),
			GUID:                types.Int64Value(int64(recordDisk.GUID)),
			DiskId:              types.Int64Value(int64(recordDisk.ID)),
			ImageID:             types.Int64Value(int64(recordDisk.ImageID)),
			Iqn:                 types.StringValue(recordDisk.IQN),
			Login:               types.StringValue(recordDisk.Login),
			Milestones:          types.Int64Value(int64(recordDisk.Milestones)),
			DiskName:            types.StringValue(recordDisk.Name),
			Order:               types.Int64Value(int64(recordDisk.Order)),
			Params:              types.StringValue(recordDisk.Params),
			ParentID:            types.Int64Value(int64(recordDisk.ParentID)),
			Passwd:              types.StringValue(recordDisk.Password),
			PCISlot:             types.Int64Value(int64(recordDisk.PCISlot)),
			Pool:                types.StringValue(recordDisk.Pool),
			PurgeAttempts:       types.Int64Value(int64(recordDisk.PurgeAttempts)),
			PurgeTime:           types.Int64Value(int64(recordDisk.PurgeTime)),
			RealityDeviceNumber: types.Int64Value(int64(recordDisk.RealityDeviceNumber)),
			ReferenceID:         types.StringValue(recordDisk.ReferenceID),
			ResID:               types.StringValue(recordDisk.ResID),
			ResName:             types.StringValue(recordDisk.ResName),
			Role:                types.StringValue(recordDisk.Role),
			SepID:               types.Int64Value(int64(recordDisk.SEPID)),
			Shareable:           types.BoolValue(recordDisk.Shareable),
			SizeMax:             types.Int64Value(int64(recordDisk.SizeMax)),
			SizeUsed:            types.Float64Value(recordDisk.SizeUsed),
			Snapshots:           flattenSnapshots(ctx, recordDisk.Snapshots),
			Status:              types.StringValue(recordDisk.Status),
			TechStatus:          types.StringValue(recordDisk.TechStatus),
			Type:                types.StringValue(recordDisk.Type),
			VMID:                types.Int64Value(int64(recordDisk.VMID)),
		}

		d.Images, diags = types.ListValueFrom(ctx, types.StringType, recordDisk.Images)
		if diags != nil {
			tflog.Error(ctx, fmt.Sprint("flattens.DiskListUnattachedDataSource: cannot flatten recordDisk.Images to d.Images", diags))
		}

		iotune := models.IOTuneModel{
			ReadBytesSec:     types.Int64Value(int64(recordDisk.IOTune.ReadBytesSec)),
			ReadBytesSecMax:  types.Int64Value(int64(recordDisk.IOTune.ReadBytesSecMax)),
			ReadIOPSSec:      types.Int64Value(int64(recordDisk.IOTune.ReadIOPSSec)),
			ReadIOPSSecMax:   types.Int64Value(int64(recordDisk.IOTune.ReadIOPSSecMax)),
			SizeIOPSSec:      types.Int64Value(int64(recordDisk.IOTune.SizeIOPSSec)),
			TotalBytesSec:    types.Int64Value(int64(recordDisk.IOTune.TotalBytesSec)),
			TotalBytesSecMax: types.Int64Value(int64(recordDisk.IOTune.TotalBytesSecMax)),
			TotalIOPSSec:     types.Int64Value(int64(recordDisk.IOTune.TotalIOPSSec)),
			TotalIOPSSecMax:  types.Int64Value(int64(recordDisk.IOTune.TotalIOPSSecMax)),
			WriteBytesSec:    types.Int64Value(int64(recordDisk.IOTune.WriteBytesSec)),
			WriteBytesSecMax: types.Int64Value(int64(recordDisk.IOTune.WriteBytesSecMax)),
			WriteIOPSSec:     types.Int64Value(int64(recordDisk.IOTune.WriteIOPSSec)),
			WriteIOPSSecMax:  types.Int64Value(int64(recordDisk.IOTune.WriteIOPSSecMax)),
		}
		obj, diags := types.ObjectValueFrom(ctx, models.ItemIOTune, iotune)
		if diags != nil {
			tflog.Error(ctx, fmt.Sprint("Error flattens.DiskListUnattachedDataSource iotune struct to obj", diags))
		}
		d.IOTune = obj

		items = append(items, d)
	}
	state.Items = items

	tflog.Info(ctx, "flattens.DiskListUnattachedDataSource: end flatten")
	return nil
}

==> 1.2.1.zip: terraform-provider-dynamix/internal/service/cloudapi/disks/flattens/flatten_data_source_disk_list_unattached.go <==
package flattens

import (
	"context"
	"encoding/json"
	"fmt"

	"github.com/google/uuid"
	"github.com/hashicorp/terraform-plugin-framework/diag"
	"github.com/hashicorp/terraform-plugin-framework/types"
	"github.com/hashicorp/terraform-plugin-log/tflog"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/client"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/flattens"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/disks/models"
	"repository.basistech.ru/BASIS/terraform-provider-dynamix/internal/service/cloudapi/disks/utilities"
)

// DiskListUnattachedDataSource flattens data source for disk list unattached.
// Return error in case data source is not found on the platform.
// Flatten errors are added to tflog.
func DiskListUnattachedDataSource(ctx context.Context, state *models.DataSourceDiskListUnattachedModel, c *client.Client) diag.Diagnostics {
	tflog.Info(ctx, "Start flattens.DiskListUnattachedDataSource")

	diags := diag.Diagnostics{}

	diskList, diags := utilities.DataSourceDiskListUnattachedCheckPresence(ctx, state, c)
	if diags.HasError() {
		return diags
	}

	tflog.Info(ctx, "flattens.DiskListUnattachedDataSource: before flatten")

	id := uuid.New()
	*state = models.DataSourceDiskListUnattachedModel{
		ByID:        state.ByID,
		AccountName: state.AccountName,
		DiskMaxSize: state.DiskMaxSize,
		Status:      state.Status,
		AccountID:   state.AccountID,
		SepID:       state.SepID,
		PoolName:    state.PoolName,
		Type:        state.Type,
		SortBy:      state.SortBy,
		Page:        state.Page,
		Size:        state.Size,
		Timeouts:    state.Timeouts,

		// computed fields
		Id:         types.StringValue(id.String()),
		EntryCount: types.Int64Value(int64(diskList.EntryCount)),
	}

	items := make([]models.ItemDiskUnattachedModel, 0, diskList.EntryCount)
	for _, recordDisk := range diskList.Data {
		diskAcl, _ := json.Marshal(recordDisk.ACL)
		d := models.ItemDiskUnattachedModel{
			CKey:                types.StringValue(recordDisk.CKey),
			Meta:                flattens.Meta(ctx, recordDisk.Meta),
			AccountID:           types.Int64Value(int64(recordDisk.AccountID)),
			AccountName:         types.StringValue(recordDisk.AccountName),
			ACL:                 types.StringValue(string(diskAcl)),
			BootPartition:       types.Int64Value(int64(recordDisk.BootPartition)),
			CreatedTime:         types.Int64Value(int64(recordDisk.CreatedTime)),
			DeletedTime:         types.Int64Value(int64(recordDisk.DeletedTime)),
			Description:         types.StringValue(recordDisk.Description),
			DestructionTime:     types.Int64Value(int64(recordDisk.DestructionTime)),
			DiskPath:            types.StringValue(recordDisk.DiskPath),
			GID:                 types.Int64Value(int64(recordDisk.GID)),
			GUID:                types.Int64Value(int64(recordDisk.GUID)),
			DiskId:              types.Int64Value(int64(recordDisk.ID)),
			ImageID:             types.Int64Value(int64(recordDisk.ImageID)),
			Iqn:                 types.StringValue(recordDisk.IQN),
			Login:               types.StringValue(recordDisk.Login),
			Milestones:          types.Int64Value(int64(recordDisk.Milestones)),
			DiskName:            types.StringValue(recordDisk.Name),
			Order:               types.Int64Value(int64(recordDisk.Order)),
			Params:              types.StringValue(recordDisk.Params),
			ParentID:            types.Int64Value(int64(recordDisk.ParentID)),
			Passwd:              types.StringValue(recordDisk.Password),
			PCISlot:             types.Int64Value(int64(recordDisk.PCISlot)),
			Pool:                types.StringValue(recordDisk.Pool),
			PurgeAttempts:       types.Int64Value(int64(recordDisk.PurgeAttempts)),
			PurgeTime:           types.Int64Value(int64(recordDisk.PurgeTime)),
			RealityDeviceNumber: types.Int64Value(int64(recordDisk.RealityDeviceNumber)),
			ReferenceID:         types.StringValue(recordDisk.ReferenceID),
			ResID:               types.StringValue(recordDisk.ResID),
			ResName:             types.StringValue(recordDisk.ResName),
			Role:                types.StringValue(recordDisk.Role),
			SepID:               types.Int64Value(int64(recordDisk.SEPID)),
			Shareable:           types.BoolValue(recordDisk.Shareable),
			SizeMax:             types.Int64Value(int64(recordDisk.SizeMax)),
			SizeUsed:            types.Float64Value(recordDisk.SizeUsed),
			Snapshots:           flattenSnapshots(ctx, recordDisk.Snapshots),
			Status:              types.StringValue(recordDisk.Status),
			TechStatus:          types.StringValue(recordDisk.TechStatus),
			Type:                types.StringValue(recordDisk.Type),
			VMID:                types.Int64Value(int64(recordDisk.VMID)),
		}

		d.Images, diags = types.ListValueFrom(ctx, types.StringType, recordDisk.Images)
		if diags != nil {
			tflog.Error(ctx, fmt.Sprint("flattens.DiskListUnattachedDataSource: cannot flatten recordDisk.Images to d.Images", diags))
		}

		iotune := models.IOTuneModel{
			ReadBytesSec:     types.Int64Value(int64(recordDisk.IOTune.ReadBytesSec)),
			ReadBytesSecMax:  types.Int64Value(int64(recordDisk.IOTune.ReadBytesSecMax)),
			ReadIOPSSec:      types.Int64Value(int64(recordDisk.IOTune.ReadIOPSSec)),
			ReadIOPSSecMax:   types.Int64Value(int64(recordDisk.IOTune.ReadIOPSSecMax)),
			SizeIOPSSec:      types.Int64Value(int64(recordDisk.IOTune.SizeIOPSSec)),
			TotalBytesSec:    types.Int64Value(int64(recordDisk.IOTune.TotalBytesSec)),
			TotalBytesSecMax: types.Int64Value(int64(recordDisk.IOTune.TotalBytesSecMax)),
			TotalIOPSSec:     types.Int64Value(int64(recordDisk.IOTune.TotalIOPSSec)),
			TotalIOPSSecMax:  types.Int64Value(int64(recordDisk.IOTune.TotalIOPSSecMax)),
			WriteBytesSec:    types.Int64Value(int64(recordDisk.IOTune.WriteBytesSec)),
			WriteBytesSecMax: types.Int64Value(int64(recordDisk.IOTune.WriteBytesSecMax)),
			WriteIOPSSec:     types.Int64Value(int64(recordDisk.IOTune.WriteIOPSSec)),
			WriteIOPSSecMax:  types.Int64Value(int64(recordDisk.IOTune.WriteIOPSSecMax)),
		}
		obj, diags := types.ObjectValueFrom(ctx, models.ItemIOTune, iotune)
		if diags != nil {
			tflog.Error(ctx, fmt.Sprint("Error flattens.DiskListUnattachedDataSource iotune struct to obj", diags))
		}
		d.IOTune = obj

		items = append(items, d)
	}
	state.Items = items

	tflog.Info(ctx, "flattens.DiskListUnattachedDataSource: end flatten")
	return nil
}
